function [x_zoom] = zoom_step_2D(x_out, threshold, Qblock, M, N, t, y, alpha)

%zooming into BandLasso
predicted_bands = (abs(x_out) > threshold); %find active bands
nr = sum(predicted_bands); % number of predcited bands
fBlock = linspace(0,.999,Qblock*M+1); 
if nr > 0
    loc = find(abs(x_out) > threshold); %location of predicted bands
    x_zoom = zeros(Qblock*M, Qblock*M); %expanded 2D grid
    Azoom = []; %empty dictionary
    for s=1:nr
        [s1, s2] = ind2sub([M M], loc(s)); %location of predicted bands for each dimension
        subBlock1 = fBlock((s1-1)*Qblock+1:s1*Qblock+1); %divide predicted band into subbands
        subBlock2 = fBlock((s2-1)*Qblock+1:s2*Qblock+1); %divide predicted band into subbands
        Asub = zeros(N,Qblock); %subdictionary
        for iM=1:Qblock
            a = 1./(2i*pi*t).*(exp(2i*pi*t*(subBlock1(iM+1)))-...
            exp(2i*pi*t*(subBlock1(iM))));
            Asub(:,iM) =a/norm(a);
        end;
        Asub1 = Asub;
        Asub = zeros(N,Qblock); %subdictionary
        for iM=1:Qblock
        a = 1./(2i*pi*t).*(exp(2i*pi*t*(subBlock2(iM+1)))-...
            exp(2i*pi*t*(subBlock2(iM))));
            Asub(:,iM) =a/norm(a);
        end;
        Asub2 = Asub;
        Azoom = [Azoom kron(Asub2,Asub1)]; %combine subdictionaries
    end;
    lambda = alpha*max(abs(Azoom'*y));
    [x_tmp,~,~] = ADMM_Lasso(y,Azoom,1,lambda,1e-6,1e-6,500); %solve for new dictionary
    block_location = map_location(Qblock, M); %starting indices for expanded mtx
    for s=1:nr
        data = x_tmp(Qblock*Qblock*(s-1)+1:Qblock*Qblock*s); %take one block from the solution vector
        x_zoom = remap_mtx(x_zoom, Qblock, M, data, block_location(loc(s))); %remap 1D solution to 2D 
    end;
else
    x_zoom = 0;
end;